@@ -1,5 +1,5 @@
 from typing import List
-from fibonacci_table import FibonacciTable
+from fibonacci_calculator_onion.fibonacci_table import FibonacciTable
 
 
 class FibonacciService:
@@ -16,7 +16,7 @@ class FibonacciService:
             return -1
         if self.data.forward_look_up_table.get(n) is not None:
             return self.data.forward_look_up_table[n]
-        return self.data.search_fibonacci_number(n)
+        return self.data.new_fibonacci_number(n)
 
     def get_fibonacci_index(self, fibonacci_number: int) -> int:
         """
@@ -28,7 +28,7 @@ class FibonacciService:
             return -1
         if self.data.backward_look_up_table.get(fibonacci_number) is not None:
             return self.data.backward_look_up_table.get(fibonacci_number)
-        return self.data.search_index_fibonacci_number(fibonacci_number)
+        return self.data.new_index_fibonacci_number(fibonacci_number)
 
     def get_fibonacci_sequence(self, n: int) -> List[int]:
         """
